BuildError

Enum BuildError 

pub enum BuildError {
Show 15 variants SpecifiedKeyNotUnique(Vec<String>), NotExistSpecifiedKey(String, Vec<String>), AlreadyExistKey(String), InvalidType(GeneratorType), InvalidValue(String), NotExistValueOf(String), FailParseValue(String, String, String), RangeEmpty(ValueBound<DataValue>), EmptySelectableChildren, EmptySelectValues, EmptySelectable, NotExistDefaultCase, AllWeightsZero, FileError(Error, PathBuf), FailBuildDistribution(String, String),
}
Error for generator builder

Variants



SpecifiedKeyNotUnique(Vec<String>)

Specified keys in the Schema is not unique.

Arguments

  • 0: Specified keys


NotExistSpecifiedKey(String, Vec<String>)

Specified key does not exist in generated values

Arguments

  • 0: Specified key
  • 1: Keys of generated values


AlreadyExistKey(String)

Specified key in the Schema already exist.

Arguments

  • 0: Specified key


InvalidType(GeneratorType)

Specified type in thea Schema is not valid type.

Arguments

  • 0: Specified type


InvalidValue(String)

Specified value in the Schema is not valid value.

Arguments

  • 0: Specified value’s string


NotExistValueOf(String)

Specified value’s key does not exist in the Schema.

Arguments

  • 0: Specified value’s key


FailParseValue(String, String, String)

Fail parse specified value in the Schema.

Arguments

  • 0: Parse target value
  • 1: Parse target type
  • 2: Parse error message


RangeEmpty(ValueBound<DataValue>)

Specified range in the Schema is empty range.

Arguments

  • 0: Range bound


EmptySelectableChildren

Specified children in the Schema does not exist or does not have child.



EmptySelectValues

Specified values in the Schema does not exist or does not have value.



EmptySelectable

Specified randomize values at the keys: children, chars, values, filepath is empty.



NotExistDefaultCase

Specified default case at the key case in the Schema at a child generator does not exist



AllWeightsZero

Specified some of values at the key weight in the Schema at a child generator does not exist



FileError(Error, PathBuf)

Input/Output Error for a file.

Arguments

  • 0: Error information
  • 1: Occurred filepath


FailBuildDistribution(String, String)

Error for fail build distribution with the specified parameters at the key parameters in the Schema

Arguments

  • 0: Name of the distribution
  • 1: Error information