pub enum BuildError {
Show 15 variants
SpecifiedKeyNotUnique(Vec<String>),
NotExistSpecifiedKey(String, Vec<String>),
AlreadyExistKey(String),
InvalidType(GeneratorType),
InvalidValue(String),
NotExistValueOf(String),
FailParseValue(String, String, String),
RangeEmpty(ValueBound<DataValue>),
EmptySelectableChildren,
EmptySelectValues,
EmptySelectable,
NotExistDefaultCase,
AllWeightsZero,
FileError(Error, PathBuf),
FailBuildDistribution(String, String),
}Expand description
Error for generator builder
Variants
SpecifiedKeyNotUnique(Vec<String>)
NotExistSpecifiedKey(String, Vec<String>)
Specified key does not exist in generated values
Arguments
- 0: Specified
key - 1: Keys of generated values
AlreadyExistKey(String)
InvalidType(GeneratorType)
InvalidValue(String)
NotExistValueOf(String)
FailParseValue(String, String, String)
Fail parse specified value in the Schema.
Arguments
- 0: Parse target value
- 1: Parse target type
- 2: Parse error message
RangeEmpty(ValueBound<DataValue>)
EmptySelectableChildren
Specified children in the Schema does not exist or does not have child.
EmptySelectValues
Specified values in the Schema does not exist or does not have value.
EmptySelectable
Specified randomize values at the keys: children, chars, values, filepath is empty.
NotExistDefaultCase
Specified default case at the key case in the Schema at a child generator does not exist
AllWeightsZero
Specified some of values at the key weight in the Schema at a child generator does not exist
FileError(Error, PathBuf)
FailBuildDistribution(String, String)
Error for fail build distribution with the specified parameters at the key parameters in the Schema
Arguments
- 0: Name of the distribution
- 1: Error information