pub enum DataValue {
Int(SbrdInt),
Real(SbrdReal),
Bool(SbrdBool),
String(String),
Null,
}Expand description
Value for Schema
Variants
Implementations
Sourceimpl DataValue
impl DataValue
Sourcepub fn to_permutation_string(&self) -> String
pub fn to_permutation_string(&self) -> String
Convert to String to use when permute with other Strings
Sourcepub fn to_parse_string(&self) -> String
pub fn to_parse_string(&self) -> String
Convert to String to use parse
Sourcepub fn format(&self, format: &str) -> Option<String>
pub fn format(&self, format: &str) -> Option<String>
Format this value
Support Rust-format syntax. But not support position, variable, padding with character and Pointer format ({:p}).
Debug format is not supported in release build.
Examples
fn main(){
use sbrd_gen::value::DataValue;
assert_eq!(Some("ignore value".to_string()), DataValue::Int(12).format("ignore value"));
assert_eq!(Some("12".to_string()), DataValue::Int(12).format("{}"));
assert_eq!(Some("{}".to_string()), DataValue::Int(12).format("{{}}"));
assert_eq!(Some("Rate= +12.35".to_string()), DataValue::Real(12.345).format("Rate={:+7.2}"));
assert_eq!(Some("Rate=+012.35".to_string()), DataValue::Real(12.345).format("Rate={:+07.2}"));
assert_eq!(Some(" aiueoあいうえお ".to_string()), DataValue::String("aiueoあいうえお".to_string()).format("{:^12}"));
assert_eq!(Some("true ".to_string()), DataValue::Bool(true).format("{:<8}"));
assert_eq!(Some("null".to_string()), DataValue::Null.format("{:<10}"));
}Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DataValue
impl<'de> Deserialize<'de> for DataValue
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> FormatArgument for &'a DataValue
impl<'a> FormatArgument for &'a DataValue
Sourcefn supports_format(&self, specifier: &Specifier) -> bool
fn supports_format(&self, specifier: &Specifier) -> bool
Returns
true if self can be formatted using the given specifier.Sourcefn fmt_display(&self, f: &mut Formatter<'_>) -> Result
fn fmt_display(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Display.Sourcefn fmt_debug(&self, f: &mut Formatter<'_>) -> Result
fn fmt_debug(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Debug.Sourcefn fmt_octal(&self, f: &mut Formatter<'_>) -> Result
fn fmt_octal(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Octal.Sourcefn fmt_lower_hex(&self, f: &mut Formatter<'_>) -> Result
fn fmt_lower_hex(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::LowerHex.Sourcefn fmt_upper_hex(&self, f: &mut Formatter<'_>) -> Result
fn fmt_upper_hex(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::UpperHex.Sourcefn fmt_binary(&self, f: &mut Formatter<'_>) -> Result
fn fmt_binary(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Binary.Sourcefn fmt_lower_exp(&self, f: &mut Formatter<'_>) -> Result
fn fmt_lower_exp(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::LowerExp.Sourcefn fmt_upper_exp(&self, f: &mut Formatter<'_>) -> Result
fn fmt_upper_exp(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::UpperExp.Sourcefn to_usize(&self) -> Result<usize, ()>
fn to_usize(&self) -> Result<usize, ()>
Performs a type conversion into
usize that might fail. Like TryInto<usize>, but does not
consume self. The parser uses this to support formats whose width or precision use “dollar
syntax”. For more information about these, see std::fmt. The default implementation always
returns an error.Sourceimpl FormatArgument for DataValue
impl FormatArgument for DataValue
Sourcefn supports_format(&self, specifier: &Specifier) -> bool
fn supports_format(&self, specifier: &Specifier) -> bool
Returns
true if self can be formatted using the given specifier.Sourcefn fmt_display(&self, f: &mut Formatter<'_>) -> Result
fn fmt_display(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Display.Sourcefn fmt_debug(&self, f: &mut Formatter<'_>) -> Result
fn fmt_debug(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Debug.Sourcefn fmt_octal(&self, f: &mut Formatter<'_>) -> Result
fn fmt_octal(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Octal.Sourcefn fmt_lower_hex(&self, f: &mut Formatter<'_>) -> Result
fn fmt_lower_hex(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::LowerHex.Sourcefn fmt_upper_hex(&self, f: &mut Formatter<'_>) -> Result
fn fmt_upper_hex(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::UpperHex.Sourcefn fmt_binary(&self, f: &mut Formatter<'_>) -> Result
fn fmt_binary(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::Binary.Sourcefn fmt_lower_exp(&self, f: &mut Formatter<'_>) -> Result
fn fmt_lower_exp(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::LowerExp.Sourcefn fmt_upper_exp(&self, f: &mut Formatter<'_>) -> Result
fn fmt_upper_exp(&self, f: &mut Formatter<'_>) -> Result
Formats the value the way it would be formatted if it implemented
std::fmt::UpperExp.Sourcefn to_usize(&self) -> Result<usize, ()>
fn to_usize(&self) -> Result<usize, ()>
Performs a type conversion into
usize that might fail. Like TryInto<usize>, but does not
consume self. The parser uses this to support formats whose width or precision use “dollar
syntax”. For more information about these, see std::fmt. The default implementation always
returns an error.Sourceimpl From<NaiveDateTime> for DataValue
impl From<NaiveDateTime> for DataValue
Sourcefn from(v: SbrdDateTime) -> Self
fn from(v: SbrdDateTime) -> Self
Converts to this type from the input type.
impl StructuralPartialEq for DataValue